@@ -71,7 +71,7 @@ test_that("Non-binary outcome can be in [0, 1]", {
                      A = rbinom(n, 1, .5), 
                      Y = rbinom(n, 2, .5)/2)
 
-  expect_that(ltmle(data, Anodes="A", Ynodes="Y", abar=1), is_a("ltmle"))
+  expect_that(ltmle(data, Anodes="A", Ynodes="Y", abar=1, IC.variance.only=TRUE), is_a("ltmle"))
 })
 
 test_that("survivalOutcome=TRUE requires binary outcomes.", {
@@ -81,7 +81,7 @@ test_that("survivalOutcome=TRUE requires binary outcomes.", {
                      A = rbinom(n, 1, .5), 
                      Y = rbinom(n, 2, .5)/2)
 
-  expect_that(ltmle(data, Anodes="A", Ynodes="Y", abar=1, survivalOutcome=TRUE), 
+  expect_that(ltmle(data, Anodes="A", Ynodes="Y", abar=1, survivalOutcome=TRUE, IC.variance.only=TRUE), 
     throws_error("When survivalOutcome is TRUE, all Ynodes should be 0, 1, or NA"))
 })
 
@@ -92,7 +92,7 @@ test_that("binaryOutcome flag set correctly", {
                      A = rbinom(n, 1, .5), 
                      Y = rbinom(n, 2, .5)/2)
 
-  expect_that(ltmle(data, Anodes="A", Ynodes="Y", abar=1, survivalOutcome=FALSE)$binaryOutcome, is_false())
+  expect_that(ltmle(data, Anodes="A", Ynodes="Y", abar=1, survivalOutcome=FALSE, IC.variance.only=TRUE)$binaryOutcome, is_false())
   expect_that(ltmle(transform(data, Y=round(Y)), Anodes="A", Ynodes="Y", abar=1, survivalOutcome=FALSE)$binaryOutcome, is_true())  
 })
 
@@ -104,12 +104,12 @@ test_that("Y outside of [0, 1] is scaled", {
                      A = rbinom(n, 1, .5), 
                      Y = runif(n)*10)
 
-  expect_that(l <- ltmle(data, Anodes="A", Ynodes="Y", abar=1), 
+  expect_that(l <- ltmle(data, Anodes="A", Ynodes="Y", abar=1, IC.variance.only=TRUE), 
     shows_message("Some Ynodes are not in \\[0, 1\\], and Yrange was NULL, so all Y nodes are being\\ntransformed to \\(Y-min.of.all.Ys\\)/range.of.all.Ys"))  
   expect_that(l$transformOutcome, is_true())
-  expect_that(ltmle(data, Anodes="A", Ynodes="Y", abar=1, Yrange=c(0, 3)), 
+  expect_that(ltmle(data, Anodes="A", Ynodes="Y", abar=1, Yrange=c(0, 3), IC.variance.only=TRUE), 
     shows_message("Some Ynodes are not in \\[Yrange\\[1\\], Yrange\\[2\\]\\], Y values are truncated"))
-  expect_that(ltmle(transform(data, Y=Y/10), Anodes="A", Ynodes="Y", abar=1)$transformOutcome, is_false())
+  expect_that(ltmle(transform(data, Y=Y/10), Anodes="A", Ynodes="Y", abar=1, IC.variance.only=TRUE)$transformOutcome, is_false())
 })
 
 test_that("survivalOutcome required if outcome is binary", {
